@@ -445,10 +445,10 @@ public:
   void removeAllStreams();
 
   // Test if this AnnotAppearance references the specified stream
-  bool referencesStream(Ref targetStreamRef);
+  bool referencesStream(Ref refToStream);
 
 private:
-  static bool referencesStream(const Object *stateObj, Ref targetStreamRef);
+  static bool referencesStream(const Object *stateObj, Ref refToStream);
   void removeStream(Ref refToStream);
   void removeStateStreams(const Object *state);
 
@@ -511,7 +511,7 @@ protected:
 class AnnotAppearanceBBox
 {
 public:
-  AnnotAppearanceBBox(PDFRectangle *init);
+  AnnotAppearanceBBox(PDFRectangle *rect);
 
   void setBorderWidth(double w) { borderWidth = w; }
 
@@ -684,7 +684,7 @@ public:
   // new_content should never be NULL
   virtual void setContents(GooString *new_content);
   void setName(GooString *new_name);
-  void setModified(GooString *new_date);
+  void setModified(GooString *new_modified);
   void setFlags(unsigned int new_flags);
 
   void setBorder(std::unique_ptr<AnnotBorder> &&new_border);
@@ -724,7 +724,7 @@ private:
   // write vStr[i:j[ in appearBuf
 
   void initialize (PDFDoc *docA, Dict *dict);
-  void setPage (int new_page, bool updateP); // Called by Page::addAnnot and Annots ctor
+  void setPage (int pageIndex, bool updateP); // Called by Page::addAnnot and Annots ctor
 
 
 protected:
@@ -784,7 +784,7 @@ class AnnotPopup: public Annot {
 public:
   AnnotPopup(PDFDoc *docA, PDFRectangle *rect);
   AnnotPopup(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotPopup();
+  ~AnnotPopup() override;
 
   bool hasParent() const { return parentRef != Ref::INVALID(); }
   void setParent(Annot *parentA);
@@ -811,7 +811,7 @@ public:
 
   AnnotMarkup(PDFDoc *docA, PDFRectangle *rect);
   AnnotMarkup(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotMarkup();
+  ~AnnotMarkup() override;
 
   // getters
   const GooString *getLabel() const { return label.get(); }
@@ -872,7 +872,7 @@ public:
 
   AnnotText(PDFDoc *docA, PDFRectangle *rect);
   AnnotText(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotText();
+  ~AnnotText() override;
 
   void draw(Gfx *gfx, bool printing) override;
 
@@ -905,7 +905,7 @@ class AnnotMovie: public Annot {
  public:
   AnnotMovie(PDFDoc *docA, PDFRectangle *rect, Movie *movieA);
   AnnotMovie(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotMovie();
+  ~AnnotMovie() override;
 
   void draw(Gfx *gfx, bool printing) override;
 
@@ -929,7 +929,7 @@ class AnnotScreen: public Annot {
 
   AnnotScreen(PDFDoc *docA, PDFRectangle *rect);
   AnnotScreen(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotScreen();
+  ~AnnotScreen() override;
 
   const GooString* getTitle() const { return title.get(); }
 
@@ -965,7 +965,7 @@ public:
 
   AnnotLink(PDFDoc *docA, PDFRectangle *rect);
   AnnotLink(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotLink();
+  ~AnnotLink() override;
 
   void draw(Gfx *gfx, bool printing) override;
 
@@ -1008,7 +1008,7 @@ public:
 
   AnnotFreeText(PDFDoc *docA, PDFRectangle *rect, const DefaultAppearance &da);
   AnnotFreeText(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotFreeText();
+  ~AnnotFreeText() override;
 
   void draw(Gfx *gfx, bool printing) override;
   Object getAppearanceResDict() override;
@@ -1071,7 +1071,7 @@ public:
 
   AnnotLine(PDFDoc *docA, PDFRectangle *rect);
   AnnotLine(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotLine();
+  ~AnnotLine() override;
 
   void draw(Gfx *gfx, bool printing) override;
   Object getAppearanceResDict() override;
@@ -1138,7 +1138,7 @@ public:
 
   AnnotTextMarkup(PDFDoc *docA, PDFRectangle *rect, AnnotSubtype subType);
   AnnotTextMarkup(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotTextMarkup();
+  ~AnnotTextMarkup() override;
 
   void draw(Gfx *gfx, bool printing) override;
 
@@ -1165,7 +1165,7 @@ public:
 
   AnnotStamp(PDFDoc *docA, PDFRectangle *rect);
   AnnotStamp(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotStamp();
+  ~AnnotStamp() override;
 
   void setIcon(GooString *new_icon);
 
@@ -1188,7 +1188,7 @@ public:
 
   AnnotGeometry(PDFDoc *docA, PDFRectangle *rect, AnnotSubtype subType);
   AnnotGeometry(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotGeometry();
+  ~AnnotGeometry() override;
 
   void draw(Gfx *gfx, bool printing) override;
 
@@ -1224,7 +1224,7 @@ public:
 
   AnnotPolygon(PDFDoc *docA, PDFRectangle *rect, AnnotSubtype subType);
   AnnotPolygon(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotPolygon();
+  ~AnnotPolygon() override;
 
   void draw(Gfx *gfx, bool printing) override;
   void generatePolyLineAppearance(AnnotAppearanceBuilder* appearBuilder);
@@ -1274,7 +1274,7 @@ public:
 
   AnnotCaret(PDFDoc *docA, PDFRectangle *rect);
   AnnotCaret(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotCaret();
+  ~AnnotCaret() override;
 
   void setSymbol(AnnotCaretSymbol new_symbol);
 
@@ -1299,7 +1299,7 @@ public:
 
   AnnotInk(PDFDoc *docA, PDFRectangle *rect);
   AnnotInk(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotInk();
+  ~AnnotInk() override;
 
   void draw(Gfx *gfx, bool printing) override;
 
@@ -1334,7 +1334,7 @@ public:
 
   AnnotFileAttachment(PDFDoc *docA, PDFRectangle *rect, GooString *filename);
   AnnotFileAttachment(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotFileAttachment();
+  ~AnnotFileAttachment() override;
 
   void draw(Gfx *gfx, bool printing) override;
 
@@ -1362,7 +1362,7 @@ public:
 
   AnnotSound(PDFDoc *docA, PDFRectangle *rect, Sound *soundA);
   AnnotSound(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotSound();
+  ~AnnotSound() override;
 
   void draw(Gfx *gfx, bool printing) override;
 
@@ -1397,11 +1397,11 @@ public:
 
   AnnotWidget(PDFDoc *docA, Object &&dictObject, const Object *obj);
   AnnotWidget(PDFDoc *docA, Object *dictObject, Object *obj, FormField *fieldA);
-  ~AnnotWidget();
+  ~AnnotWidget() override;
 
   void draw(Gfx *gfx, bool printing) override;
 
-  void generateFieldAppearance (bool *addDingbatsResource);
+  void generateFieldAppearance (bool *addedDingbatsResource);
   void updateAppearanceStream ();
 
   AnnotWidgetHighlightMode getMode() { return mode; }
@@ -1478,7 +1478,7 @@ public:
 
   Annot3D(PDFDoc *docA, PDFRectangle *rect);
   Annot3D(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~Annot3D();
+  ~Annot3D() override;
 
   // getters
 
@@ -1658,7 +1658,7 @@ public:
 
   AnnotRichMedia(PDFDoc *docA, PDFRectangle *rect);
   AnnotRichMedia(PDFDoc *docA, Object &&dictObject, const Object *obj);
-  ~AnnotRichMedia();
+  ~AnnotRichMedia() override;
 
   Content* getContent() const;
 
